@@ -9,7 +9,7 @@ import requests
 
 # Local imports
 from pycid_dev.lib.tree.tree import Tree, deserialize
-from pycid_dev.lib.craft.craft import Craft
+from pycid_dev.lib.tree.tree import Craft
 from pycid_dev.lib.authentication.authentication import Authentication
 
 
@@ -70,40 +70,40 @@ class CidClient:
     #
     # User information queries
     #
-    def crafts_info(self):
+    def trees_info(self):
         """
-        Gets the crafts available and the elements that it is composed of.
+        Gets the trees available and the elements that it is composed of.
         """
         return self._user_info["user"]["trees"]
 
-    def fetch_craft(self, craft_id):
+    def fetch_tree(self, tree_id):
         """
-        Pull all data for a craft from the network. Push it into a new Craft
+        Pull all data for a tree from the network. Push it into a new Craft
 
         :returns A Craft object
 
         NOTE: this performs a network query
         """
-        # Find the elements that the craft is composed of
-        craft = None
-        for craft_info in self.crafts_info():
-            if craft_info["id"] == craft_id:
-                craft = craft_info
-        if not craft:
-            raise ValueError("Provided craft id could not be found")
+        # Find the elements that the tree is composed of
+        tree = None
+        for tree_info in self.trees_info():
+            if tree_info["id"] == tree_id:
+                tree = tree_info
+        if not tree:
+            raise ValueError("Provided tree id could not be found")
 
-        # Pull down all the crates associated with the craft
+        # Pull down all the crates associated with the tree
         # TODO might want to keep these separated? or at a minimum store a mapping from node id to crate id that it belongs to
         aggregate_crate = []
-        for crate in craft["crate_ids"]:
+        for crate in tree["crate_ids"]:
             aggregate_crate += self._fetch_instance_crate(crate)["payload"]["crates"]
 
-        # Pull down and create the tree associated with the craft
-        if len(craft["frame_ids"]) > 1:
+        # Pull down and create the tree associated with the tree
+        if len(tree["frame_ids"]) > 1:
             raise ValueError("The Python client does not support multiple frames at this time")
-        the_tree = self._fetch_instance_tree(craft["frame_ids"][0])
+        the_tree = self._fetch_instance_tree(tree["frame_ids"][0])
 
-        return Craft(craft["name"], craft["id"], aggregate_crate, the_tree,
+        return Craft(tree["name"], tree["id"], aggregate_crate, the_tree,
                      {"component_resync_query": self._component_resync_query,
                       "component_resync_execute": self._component_resync_execute,
                       "component_attribute_edit": self._component_attribute_edit,
