@@ -49,7 +49,7 @@ class Craft(object):
         possible_crate_ids = [crate["id"] for crate in self._cache.crates]
         if crate_id and crate_id not in possible_crate_ids:
             raise ValueError(
-                f"Could not find crate id: {crate_id} for craft: {self.name()}")
+                f"Could not find crate id: {crate_id} for tree: {self.name()}")
 
         # Figure out which crates we should query
         requested_crate_ids = []
@@ -59,19 +59,19 @@ class Craft(object):
             requested_crate_ids = possible_crate_ids
 
         # The main grab all the goodies
-        items = []
+        nodes = []
         for crate in self._cache.crates:
             if crate["id"] not in requested_crate_ids:
                 continue
 
-            items_to_append = crate["items"]
+            nodes_to_append = crate["nodes"]
             # Append in the crate id so the component can make network queries alone
-            for n in items_to_append:
+            for n in nodes_to_append:
                 n["crate_id"] = crate["id"]
-            items += items_to_append
+            nodes += nodes_to_append
 
-        # Make a crate with the current items in the craft, plus network callbacks that it needs
-        return Crate(items, requested_crate_ids, {k: self._network_callbacks[k] for k in ["component_resync_query",
+        # Make a crate with the current nodes in the tree, plus network callbacks that it needs
+        return Crate(nodes, requested_crate_ids, {k: self._network_callbacks[k] for k in ["component_resync_query",
                                                                                           "component_resync_execute",
                                                                                           "component_attribute_edit",
                                                                                           "component_attribute_remove",
